#!/bin/sh
# -*- mode: sh; indent-tabs-mode: nil; sh-basic-offset: 4; -*-
# vim: et sts=4 sw=4

#  SPDX-License-Identifier: LGPL-2.1+
#
#  Copyright © 2020-2021 Collabora Ltd.
#  Copyright © 2020-2021 Valve Corporation.
#
#  This file is part of steamos-customizations.
#
#  steamos-customizations is free software; you can redistribute it and/or modify
#  it under the terms of the GNU Lesser General Public License as published
#  by the Free Software Foundation; either version 2.1 of the License, or
#  (at your option) any later version.

UDEV_SYMLINKS_RELDIR=disk/by-partsets

. /lib/dracut-lib.sh

mount_var() {

    # Mount the /var mountpoint

    info "Mounting /dev/${UDEV_SYMLINKS_RELDIR}/self/var"
    mount "/dev/${UDEV_SYMLINKS_RELDIR}/self/var" "$NEWROOT/var" 2>&1 | vinfo
    if ismounted "$NEWROOT/var"; then
        return 0
    fi

    # Mount the /var mountpoint using tmpfs

    warn "Mounting /dev/${UDEV_SYMLINKS_RELDIR}/self/var failed! Fallback using tmpfs!"
    mount -t tmpfs -o size=512m tmpfs "$NEWROOT/var" 2>&1 | vinfo
    if ismounted "$NEWROOT/var"; then
        return 0
    fi

    warn "Mounting /dev/${UDEV_SYMLINKS_RELDIR}/self/var failed! Compile the kernel with CONFIG_TMPFS!"
    warn "*** Dropping you to a shell; the system will continue"
    warn "*** when you leave the shell."
    emergency_shell
}

mount_var
